@@ -1,10 +1,14 @@
+# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin,unused-import
 """
 Main interface for license-manager service client paginators.
 
 Usage::
 
+    ```python
     import boto3
-    from mypy_boto3.license_manager import (
+
+    from mypy_boto3_license_manager import LicenseManagerClient
+    from mypy_boto3_license_manager.paginator import (
         ListAssociationsForLicenseConfigurationPaginator,
         ListLicenseConfigurationsPaginator,
         ListLicenseSpecificationsForResourcePaginator,
@@ -19,10 +23,12 @@ Usage::
     list_license_specifications_for_resource_paginator: ListLicenseSpecificationsForResourcePaginator = client.get_paginator("list_license_specifications_for_resource")
     list_resource_inventory_paginator: ListResourceInventoryPaginator = client.get_paginator("list_resource_inventory")
     list_usage_for_license_configuration_paginator: ListUsageForLicenseConfigurationPaginator = client.get_paginator("list_usage_for_license_configuration")
+    ```
 """
-# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
-from typing import Iterator, List, TYPE_CHECKING
+from typing import Iterator, List
+
 from botocore.paginate import Paginator as Boto3Paginator
+
 from mypy_boto3_license_manager.type_defs import (
     FilterTypeDef,
     InventoryFilterTypeDef,
@@ -34,7 +40,6 @@ from mypy_boto3_license_manager.type_defs import (
     PaginatorConfigTypeDef,
 )
 
-
 __all__ = (
     "ListAssociationsForLicenseConfigurationPaginator",
     "ListLicenseConfigurationsPaginator",
@@ -46,20 +51,20 @@ __all__ = (
 
 class ListAssociationsForLicenseConfigurationPaginator(Boto3Paginator):
     """
-    [Paginator.ListAssociationsForLicenseConfiguration documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.17/reference/services/license-manager.html#LicenseManager.Paginator.ListAssociationsForLicenseConfiguration)
+    [Paginator.ListAssociationsForLicenseConfiguration documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.24/reference/services/license-manager.html#LicenseManager.Paginator.ListAssociationsForLicenseConfiguration)
     """
 
     def paginate(
         self, LicenseConfigurationArn: str, PaginationConfig: PaginatorConfigTypeDef = None
     ) -> Iterator[ListAssociationsForLicenseConfigurationResponseTypeDef]:
         """
-        [ListAssociationsForLicenseConfiguration.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.17/reference/services/license-manager.html#LicenseManager.Paginator.ListAssociationsForLicenseConfiguration.paginate)
+        [ListAssociationsForLicenseConfiguration.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.24/reference/services/license-manager.html#LicenseManager.Paginator.ListAssociationsForLicenseConfiguration.paginate)
         """
 
 
 class ListLicenseConfigurationsPaginator(Boto3Paginator):
     """
-    [Paginator.ListLicenseConfigurations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.17/reference/services/license-manager.html#LicenseManager.Paginator.ListLicenseConfigurations)
+    [Paginator.ListLicenseConfigurations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.24/reference/services/license-manager.html#LicenseManager.Paginator.ListLicenseConfigurations)
     """
 
     def paginate(
@@ -69,26 +74,26 @@ class ListLicenseConfigurationsPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[ListLicenseConfigurationsResponseTypeDef]:
         """
-        [ListLicenseConfigurations.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.17/reference/services/license-manager.html#LicenseManager.Paginator.ListLicenseConfigurations.paginate)
+        [ListLicenseConfigurations.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.24/reference/services/license-manager.html#LicenseManager.Paginator.ListLicenseConfigurations.paginate)
         """
 
 
 class ListLicenseSpecificationsForResourcePaginator(Boto3Paginator):
     """
-    [Paginator.ListLicenseSpecificationsForResource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.17/reference/services/license-manager.html#LicenseManager.Paginator.ListLicenseSpecificationsForResource)
+    [Paginator.ListLicenseSpecificationsForResource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.24/reference/services/license-manager.html#LicenseManager.Paginator.ListLicenseSpecificationsForResource)
     """
 
     def paginate(
         self, ResourceArn: str, PaginationConfig: PaginatorConfigTypeDef = None
     ) -> Iterator[ListLicenseSpecificationsForResourceResponseTypeDef]:
         """
-        [ListLicenseSpecificationsForResource.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.17/reference/services/license-manager.html#LicenseManager.Paginator.ListLicenseSpecificationsForResource.paginate)
+        [ListLicenseSpecificationsForResource.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.24/reference/services/license-manager.html#LicenseManager.Paginator.ListLicenseSpecificationsForResource.paginate)
         """
 
 
 class ListResourceInventoryPaginator(Boto3Paginator):
     """
-    [Paginator.ListResourceInventory documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.17/reference/services/license-manager.html#LicenseManager.Paginator.ListResourceInventory)
+    [Paginator.ListResourceInventory documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.24/reference/services/license-manager.html#LicenseManager.Paginator.ListResourceInventory)
     """
 
     def paginate(
@@ -97,13 +102,13 @@ class ListResourceInventoryPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[ListResourceInventoryResponseTypeDef]:
         """
-        [ListResourceInventory.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.17/reference/services/license-manager.html#LicenseManager.Paginator.ListResourceInventory.paginate)
+        [ListResourceInventory.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.24/reference/services/license-manager.html#LicenseManager.Paginator.ListResourceInventory.paginate)
         """
 
 
 class ListUsageForLicenseConfigurationPaginator(Boto3Paginator):
     """
-    [Paginator.ListUsageForLicenseConfiguration documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.17/reference/services/license-manager.html#LicenseManager.Paginator.ListUsageForLicenseConfiguration)
+    [Paginator.ListUsageForLicenseConfiguration documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.24/reference/services/license-manager.html#LicenseManager.Paginator.ListUsageForLicenseConfiguration)
     """
 
     def paginate(
@@ -113,5 +118,5 @@ class ListUsageForLicenseConfigurationPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[ListUsageForLicenseConfigurationResponseTypeDef]:
         """
-        [ListUsageForLicenseConfiguration.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.17/reference/services/license-manager.html#LicenseManager.Paginator.ListUsageForLicenseConfiguration.paginate)
+        [ListUsageForLicenseConfiguration.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.24/reference/services/license-manager.html#LicenseManager.Paginator.ListUsageForLicenseConfiguration.paginate)
         """
